# Начните!

Добро пожаловать в Rapunzel, современную среду разработки для Python и R. Вот несколько удобных сочетаний клавиш.


## Работа с папками и файлами проекта

- [`Ctrl+Shift+O`: Открыть папку проекта](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Открыть файл из папок проекта](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Создать пустой документ](opensesame://event.ide_new_file)


## Быстрые операции

- [`Ctrl+Shift+P`: Активировать палитру команд](opensesame://event.command_palette_activate)
- `Ctrl+R`: Перейти к функции или классу


## Запуск кода

- `F5`: Запустить проект или файл
- `F9`: Выполнить выделение, ячейку или текущую строку